Finally, the “Mail Kimp” remix you never knew you wanted · Great Job, Internet! · The A.V. Club
Description: By now the Serial theme song has been chopped a screwed a million different ways by a million different people, including us for our Serial Serial podcast. But that little kid that says “mail kimp?” That’s a different story. Soundcloud user kpffkl has created the “Mail Kimp Remix” to give that littl
Date: 2014-12-12T12:06:00-06:00

## AUX

Great Job, Internet!

# Finally, the “Mail Kimp” remix you never knew you wanted

Courtesy of MailChimp's Instagram page
Courtesy of MailChimp's Instagram page
By Marah Eakin@marahe
Dec 12, 2014 12:06 PM

- Comments

- Comments

By now the Serial theme song has been chopped a screwed a million different ways by a million different people, including us for our Serial Serial podcast. But that little kid that says “mail kimp?” That’s a different story. Soundcloud user kpffkl has created the “Mail Kimp Remix” to give that little kid some glory, and it’s both annoying and mesmerizing, as most remixes of a single sound are, but it’s still new and potentially interesting Serial-related content, something the Internet is certainly hungry for this holiday season.

[via Buzzfeed]

Filed Under: AUX, Serial, The Serial Serial, Mail Kimp, Mail Chimp

- Comments

## More Great Job, Internet!

### Suggested Reads

### More Great Job, Internet!

# Patrick Stewart remains adorable, can’t stop laughing at this silly Christmas hat

Dec 29, 2014 1:36 PM

# Epic fan-made “Marvel vs. DC” trailer pairs explosions with grimacing superheroes

Dec 22, 2014 4:06 PM

# Celebrate your hatred of Christmas with a supercut of film and TV Scrooges

Dec 22, 2014 2:39 PM

# Get a Log Lady tattoo in time for the holidays with these Twin Peaks pinups

Dec 19, 2014 4:10 PM